@@ -677,7 +677,7 @@ class Obraz(Mail_sender):
     for k in keys_:
       keys += " " + k
 
-    name_of_file = mode+" "+ keys + ".docx"
+    name_of_file = mode+" " + transliterate(keys) + ".docx"
 
     self._make_fast_book_dokument_docx(name_of_file, keys, title=mode+" "+keys, mode=mode)
 
